Result

com.codacy.plugins.api.results.Result
See theResult companion trait
object Result

Attributes

Companion
trait
Graph
Supertypes
trait Sum
trait Mirror
class Object
trait Matchable
class Any
Self type
Result.type

Members list

Type members

Classlikes

case class FileError(filename: File, message: Option[ErrorMessage]) extends Result

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
trait Result
class Object
trait Matchable
class Any
Show all
case class Issue(filename: File, message: Message, patternId: Id, line: Line, suggestion: Option[Suggestion], sourceId: Option[String], extraFields: Option[String]) extends Result

Value parameters

extraFields

Tool-specific structured metadata as a raw JSON string (e.g. Trivy dependency chains). Kept as a String to preserve this module's dependency-free, Scala-Native-friendly design; JSON (de)serialization of the embedded value is handled by the codecs in codacy-plugins.

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
trait Result
class Object
trait Matchable
class Any
Show all
object Level extends Enumeration

Attributes

Supertypes
class Enumeration
trait Serializable
class Object
trait Matchable
class Any
Self type
Level.type
case class Lines(begin: Line, end: Option[Line])

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
case class Location(path: File, lines: Option[Lines], positions: Option[Positions])

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
final case class Message(value: String) extends AnyVal

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class AnyVal
trait Matchable
class Any
Show all
case class Position(line: Line, column: Option[Int])

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
case class Positions(begin: Position, end: Option[Position])

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
case class SBOM(bomFormat: Value, specVersion: String, sbom: String) extends Result

SBOM - Software Bill of Materials

SBOM - Software Bill of Materials

A SBOM declares the inventory of components used to build a software artifact, including any open source and proprietary software components.

Value parameters

bomFormat

The format of the SBOM. Currently only CycloneDX specification in JSON format is supported.

sbom

The actual SBOM content. To be parsed by downstream consumers according to bomFormat and specVersion.

specVersion

The version of the SBOM format used to build this SBOM.

Attributes

Companion
object
Supertypes
trait Serializable
trait Product
trait Equals
trait Result
class Object
trait Matchable
class Any
Show all
object SBOM

Attributes

Companion
class
Supertypes
trait Product
trait Mirror
class Object
trait Matchable
class Any
Self type
SBOM.type
final case class Suggestion(value: String) extends AnyVal

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class AnyVal
trait Matchable
class Any
Show all

Types

type Level = Value

Inherited types

type MirroredElemLabels <: Tuple

The names of the product elements

The names of the product elements

Attributes

Inherited from:
Mirror
type MirroredLabel <: String

The name of the type

The name of the type

Attributes

Inherited from:
Mirror